"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getConfig = getConfig;
exports.getConfigPath = getConfigPath;
exports.setConfig = setConfig;

var _path = _interopRequireDefault(require("path"));

var _bluebird = _interopRequireDefault(require("bluebird"));

var _invariant = _interopRequireDefault(require("invariant"));

var _fs = _interopRequireDefault(require("./util/fs"));

const DEFAULT_ENVIRONMENT_NAME = 'dev';
const DEFAULT_CONFIG = {
  defaultNavy: DEFAULT_ENVIRONMENT_NAME,
  externalIP: null
};

const mkdirp = _bluebird.default.promisify(require('mkdirp'));

let _config = null;

function getConfigPath() {
  const home = process.env.HOME;
  (0, _invariant.default)(home, "NO_HOME_DIRECTORY: No home directory available");
  return _path.default.join(home, '.navy', 'config.json');
}

function getConfig() {
  if (_config) {
    return _config;
  }

  try {
    const file = _fs.default.readFileSync(getConfigPath(), 'utf8');

    _config = JSON.parse(file);
    return _config;
  } catch (ex) {
    return DEFAULT_CONFIG;
  }
}

async function setConfig(config) {
  if (config == null) config = DEFAULT_CONFIG;
  await mkdirp(_path.default.dirname(getConfigPath()));
  await _fs.default.writeFileAsync(getConfigPath(), JSON.stringify(config, null, 2)); // trash cached config

  _config = null;
}