"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.reconfigureHTTPProxy = reconfigureHTTPProxy;

var _os = _interopRequireDefault(require("os"));

var _path = _interopRequireDefault(require("path"));

var _jsYaml = _interopRequireDefault(require("js-yaml"));

var _dockerClient = _interopRequireDefault(require("./util/docker-client"));

var _fs = _interopRequireDefault(require("./util/fs"));

var _execAsync = require("./util/exec-async");

var _driverLogging = require("./driver-logging");

var _navy = require("./navy");

async function updateComposeConfig(navies) {
  const networks = await _dockerClient.default.listNetworks().filter(net => net.Name.indexOf('_') !== -1) // is docker-compose network?
  .filter(net => {
    for (const navy of navies) {
      if (net.Name.indexOf(navy + '_') === 0) {
        return true;
      }
    }

    return false;
  });
  const networksConfig = {};
  networks.forEach(net => networksConfig[net.Name] = {
    external: true
  });
  const config = {
    version: '2',
    services: {
      'nginx-proxy': {
        image: 'navycloud/navy-proxy',
        ports: ['80:80'],
        networks: networks.map(net => net.Name),
        volumes: ['/var/run/docker.sock:/tmp/docker.sock:ro'],
        restart: 'always'
      }
    },
    networks: networksConfig
  };
  await _fs.default.writeFileAsync(_path.default.join(_os.default.tmpdir(), 'navyinternaldockercompose.yml'), _jsYaml.default.dump(config));
}

async function reconfigureHTTPProxy(opts = {}) {
  if (!opts.navies) opts.navies = await (0, _navy.getLaunchedNavyNames)();
  await updateComposeConfig(opts.navies);
  (0, _driverLogging.log)('Configuring HTTP proxy...');
  await (0, _execAsync.execAsync)('docker-compose', ['-f', _path.default.join(_os.default.tmpdir(), 'navyinternaldockercompose.yml'), '-p', 'navyinternal', 'up', '-d']);
}