"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = hasUpdate;

var _simpleDockerRegistryClient = require("simple-docker-registry-client");

var _registryClient = require("./registry-client");

var _dockerClient = _interopRequireDefault(require("./docker-client"));

async function hasUpdate(imageWithTag, currentImageId, navyFile) {
  const imageConfig = await _dockerClient.default.getImage(currentImageId).inspect();
  const currentImageContainerId = imageConfig.ContainerConfig.Image;
  const image = (0, _simpleDockerRegistryClient.imageFromImageWithTag)(imageWithTag);
  const client = await (0, _registryClient.getRegistryClient)(image, navyFile);
  let manifest;

  try {
    manifest = await client.request((0, _simpleDockerRegistryClient.localImageFromImage)(image) + '/manifests/' + (0, _simpleDockerRegistryClient.tagFromImageWithTag)(imageWithTag));
  } catch (ex) {
    if (ex.body && ex.body.errors[0].code === 'MANIFEST_UNKNOWN') {
      return 'UNKNOWN_REMOTE';
    }

    return 'UNKNOWN_ERROR';
  }

  const lastLayer = JSON.parse(manifest.history[0].v1Compatibility);
  return lastLayer.container_config.Image !== currentImageContainerId;
}

module.exports = exports.default;