"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.credentialsFromAuth = credentialsFromAuth;
exports.getAuthForRegistry = getAuthForRegistry;
exports.getRegistryClient = getRegistryClient;
exports.registryFromImage = registryFromImage;

var _path = _interopRequireDefault(require("path"));

var _invariant = _interopRequireDefault(require("invariant"));

var _simpleDockerRegistryClient = require("simple-docker-registry-client");

var _fs = _interopRequireDefault(require("./fs"));

const DEFAULT_REGISTRY = 'registry-1.docker.io'; // docker v2 registry URL

const DEFAULT_REGISTRY_AUTH = 'https://index.docker.io/v1/'; // the url which docker stores in .docker/config.json for auth

async function getDockerUserConfig() {
  (0, _invariant.default)(process.env.HOME, "NO_HOME_DIRECTORY: No home directory available");

  try {
    const rawConfig = await _fs.default.readFileAsync(_path.default.join(process.env.HOME, '.docker', 'config.json'));
    const config = JSON.parse(rawConfig);
    return config;
  } catch (ex) {
    return null;
  }
}

function getAuthForRegistry(registry, dockerUserConfig) {
  if (registry === DEFAULT_REGISTRY) {
    registry = DEFAULT_REGISTRY_AUTH;
  }

  if (dockerUserConfig && dockerUserConfig.auths && dockerUserConfig.auths[registry]) {
    return dockerUserConfig.auths[registry];
  }

  return null;
}

function registryFromImage(image) {
  const parsedRegistry = image.match(/([a-zA-Z0-9-.:]+)\/[a-zA-Z0-9-]+\/[a-zA-Z0-9-]+/);
  const registry = parsedRegistry != null && parsedRegistry.length > 1 ? parsedRegistry[1] : DEFAULT_REGISTRY;
  return registry;
}

function credentialsFromAuth(auth) {
  if (auth && auth.auth) {
    (0, _invariant.default)(auth.auth.match(/^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{4}|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)$/) != null, "DOCKER_CONFIG_INVALID_AUTH_BASE64: Invalid base64 string in docker/config.json for registry authentication");
    const decoded = Buffer.from(auth.auth, 'base64').toString();
    const parts = decoded.split(':');
    return {
      username: parts[0],
      password: parts[1]
    };
  }

  return null;
}

async function getRegistryClient(image, navyFile) {
  const registry = registryFromImage(image);
  const opts = {
    registry: `https://${registry}`,
    allowUnauthorized: navyFile && navyFile.ignoreUnauthorizedRequestsForRegistries && navyFile.ignoreUnauthorizedRequestsForRegistries.indexOf(registry) !== -1
  }; // try and work out auth

  const auth = getAuthForRegistry(registry, await getDockerUserConfig());
  opts.credentials = credentialsFromAuth(auth);
  return {
    request: url => (0, _simpleDockerRegistryClient.registryRequest)(url, opts)
  };
}