"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createHostForService = createHostForService;
exports.createUrlForService = createUrlForService;
exports.getNIPSubdomain = getNIPSubdomain;
exports.getUrlFromService = getUrlFromService;
const BASE = 'nip.io';

function isValidIpv4Addr(ip) {
  return /^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/g.test(ip);
}

async function getNIPSubdomain(externalIP) {
  if (!isValidIpv4Addr(externalIP)) {
    // invalid IP address, fallback to local
    return `127.0.0.1.${BASE}`;
  }

  return `${externalIP}.${BASE}`;
}

async function createHostForService(service, navyNormalisedName, externalIP) {
  return `${service}.${navyNormalisedName}.${process.env.NAVY_EXTERNAL_SUBDOMAIN || (await getNIPSubdomain(externalIP))}`;
}

async function createUrlForService(service, navyNormalisedName, externalIP) {
  return `http://${await createHostForService(service, navyNormalisedName, externalIP)}`;
}

function getUrlFromService(service) {
  if (!service || !service.raw || !service.raw.Config || !service.raw.Config.Env) {
    return null;
  }

  const env = service.raw.Config.Env;

  for (const envVar of env) {
    if (envVar.indexOf('VIRTUAL_HOST=') === 0) {
      return 'http://' + envVar.substring('VIRTUAL_HOST='.length);
    }
  }

  return null;
}